=== added file '.gitlab-ci.yml'
--- .gitlab-ci.yml	1970-01-01 00:00:00 +0000
+++ .gitlab-ci.yml	2016-05-18 09:51:05 +0000
@@ -0,0 +1,47 @@
+image: ubuntu:xenial
+
+cache:
+  key: apt-cache
+  paths:
+  - apt-cache/
+
+before_script:
+  - export APT_CACHE_DIR=`pwd`/apt-cache && mkdir -pv $APT_CACHE_DIR
+  - apt-get update -yq && apt-get -o dir::cache::archives="$APT_CACHE_DIR" install -yq autotools-dev gobject-introspection gtk-doc-tools libgirepository1.0-dev libglib2.0-dev libtool python3 python3-gi python-gi-dev signond-dev
+  - apt-get -o dir::cache::archives="$APT_CACHE_DIR" install -yq signon-plugin-ssotest check dbus-test-runner lcov gcovr
+
+build_amd64:
+  stage: build
+  script:
+    - export PYTHON=python3
+    - mkdir build
+    - cd build
+    - ../autogen.sh --enable-gtk-doc --enable-gcov --enable-debug --enable-python --prefix=/usr
+    - make -j 4
+  artifacts:
+    paths:
+      - ./
+
+test_amd64:
+  stage: test
+  script:
+    - cd build
+    - make check || (cat tests/test-suite.log && /bin/false)
+    - make coverage-html
+  dependencies:
+    - build_amd64
+  artifacts:
+    paths:
+      - ./
+
+pages:
+  stage: deploy
+  script:
+    - mkdir public
+    - cp -a build/coveragereport public/coverage
+    - cp -a build/docs/reference/html/* public/
+  dependencies:
+    - test_amd64
+  artifacts:
+    paths:
+      - public

=== modified file 'Makefile.am'
--- Makefile.am	2012-10-30 09:28:39 +0000
+++ Makefile.am	2016-05-18 09:45:05 +0000
@@ -12,6 +12,8 @@
 SUBDIRS += tests
 endif
 
+include $(top_srcdir)/Makefile.am.coverage
+
 pkgconfigdir = $(libdir)/pkgconfig
 pkgconfig_in_files = libsignon-glib.pc.in
 pkgconfig_DATA = $(pkgconfig_in_files:.pc.in=.pc)

=== added file 'Makefile.am.coverage'
--- Makefile.am.coverage	1970-01-01 00:00:00 +0000
+++ Makefile.am.coverage	2016-05-18 09:45:05 +0000
@@ -0,0 +1,38 @@
+
+# Coverage targets
+
+.PHONY: clean-gcda
+clean-gcda:
+	@echo Removing old coverage results
+	-$(AM_V_at)find -name '*.gcda' -print | xargs -r rm
+
+.PHONY: coverage-html generate-coverage-html clean-coverage-html
+coverage-html: clean-gcda
+	-$(AM_V_at)$(MAKE) $(AM_MAKEFLAGS) -k check
+	$(AM_V_at)$(MAKE) $(AM_MAKEFLAGS) generate-coverage-html
+
+if HAVE_GCOV
+
+generate-coverage-html:
+	@echo Collecting coverage data
+	$(AM_V_at)$(LCOV) --directory $(top_builddir) --capture --output-file coverage.info --no-checksum --compat-libtool
+	$(AM_V_at)$(LCOV) --remove coverage.info signon-enum-types.c signon-errors-enum.c signon-marshal.c "sso-*-gen.*" -o coverage.info # autogenerated files
+	$(AM_V_at)LANG=C $(GENHTML) --prefix $(top_builddir) --output-directory coveragereport --title "Code Coverage" --legend --show-details coverage.info
+
+clean-coverage-html: clean-gcda
+	-$(AM_V_at)$(LCOV) --directory $(top_builddir) -z
+	-$(AM_V_at)rm -rf coverage.info coveragereport
+
+clean-local: clean-coverage-html
+
+else
+
+generate-coverage-html:
+	$(AM_V_at)echo "Code coverage reporting not available"
+
+clean-coverage-html: clean-gcda
+	-$(AM_V_at)rm -rf coverage.info coveragereport
+
+clean-local: clean-coverage-html
+
+endif # HAVE_GCOV

=== modified file 'NEWS'
--- NEWS	2014-12-09 08:52:37 +0000
+++ NEWS	2016-05-19 15:21:34 +0000
@@ -1,5 +1,26 @@
 libsignon-glib NEWS
 
+Version 1.14
+------------
+
+* Migrate to GTask
+* Fix memory leaks reported by valgrind
+* Enable CI in gitlab.com
+* Build: add test coverage reporting
+* Build: fix parallel builds and out-of-tree builds
+* Tests: add a test for signon_auth_session_process_async()
+* Tests: allow running tests with valgrind
+
+Version 1.13
+------------
+
+* Build: don't emit a build error on deprecations
+* Build: ignore deprecations of GSimpleAsyncResult
+* pkg-config: remove unused variable
+  Fixes: https://gitlab.com/accounts-sso/libsignon-glib/issues/1
+* Tests: do not count on mechanisms being ordered
+* Introspection: mark ACL and realms as string lists, update Vala bindings
+
 Version 1.12
 ------------
 

=== removed file 'README'
--- README	2015-11-27 02:48:53 +0000
+++ README	1970-01-01 00:00:00 +0000
@@ -1,23 +0,0 @@
-Single signon authentication library for GLib applications
-----------------------------------------------------------
-
-This project is a library for managing single signon credentilas which can be
-used from GLib applications. It is effectively a GLib binding for the D-Bus API
-provided by signond. It is part of the accounts-sso project:
-
-https://gitlab.com/groups/accounts-sso
-
-Dependencies
-------------
-
-The project depends on GLib (including GIO and GObject), signond and check.
-
-Licence
--------
-
-The library is licensed under the GNU LGPL version 2.1.
-
-Resources
----------
-
-https://gitlab.com/accounts-sso/libsignon-glib

=== added file 'README.md'
--- README.md	1970-01-01 00:00:00 +0000
+++ README.md	2016-05-19 15:13:07 +0000
@@ -0,0 +1,29 @@
+Single signon authentication library for GLib applications
+==========================================================
+
+This project is a library for managing single signon credentilas which can be
+used from GLib applications. It is effectively a GLib binding for the D-Bus API
+provided by [signond][].
+It is part of the accounts-sso project:
+
+https://gitlab.com/groups/accounts-sso
+
+Dependencies
+------------
+
+The project depends on GLib (including GIO and GObject), [signond][] and [check][].
+
+Licence
+-------
+
+The library is licensed under the GNU LGPL version 2.1.
+
+Resources
+---------
+
+[API reference documentation](http://accounts-sso.gitlab.io/libsignon-glib/)
+
+[Official source code repository](https://gitlab.com/accounts-sso/libsignon-glib)
+
+[signond]: https://gitlab.com/accounts-sso/signond
+[check]: https://github.com/libcheck/check

=== modified file 'configure.ac'
--- configure.ac	2016-05-04 13:45:23 +0000
+++ configure.ac	2016-05-19 15:28:09 +0000
@@ -1,7 +1,7 @@
 dnl Process this file with autoconf to produce a configure script.
 AC_PREREQ([2.64])
 AC_INIT([libsignon-glib],
-        [1.13],
+        [1.14],
         [https://gitlab.com/accounts-sso/libsignon-glib/issues],
         [libsignon-glib],
         [https://gitlab.com/accounts-sso/libsignon-glib])
@@ -11,7 +11,7 @@
 AC_CONFIG_SRCDIR([libsignon-glib.pc.in])
 AC_CONFIG_MACRO_DIR([m4])
 
-AM_INIT_AUTOMAKE([1.11 -Wall check-news nostdinc silent-rules subdir-objects])
+AM_INIT_AUTOMAKE([1.11 -Wall check-news nostdinc silent-rules subdir-objects foreign])
 
 AC_PROG_CC
 AC_PROG_CC_STDC
@@ -51,6 +51,13 @@
   [AS_IF([test "x$enable_tests" = "xyes"],
     [AC_MSG_ERROR([tests enabled but required dependencies were not found])])])
 
+# gcov coverage reporting
+m4_include([m4/gcov.m4])
+AC_TDD_GCOV
+AC_SUBST(COVERAGE_CFLAGS)
+AC_SUBST(COVERAGE_CXXFLAGS)
+AC_SUBST(COVERAGE_LDFLAGS)
+
 AM_CONDITIONAL([ENABLE_TESTS], [test "x$have_check" = "xyes"])
 
 GTK_DOC_CHECK([1.14], [--flavour no-tmpl])
@@ -75,11 +82,6 @@
 AS_IF([test "x$enable_debug" = "xyes"],
     [CFLAGS="$CFLAGS -DENABLE_DEBUG"])
 
-AC_ARG_ENABLE([coverage],
-    [AS_HELP_STRING([--enable-coverage], [compile with coverage info])])
-AS_IF([test "x$enable_coverage" = "xyes"],
-    [CFLAGS="$CFLAGS -g -fprofile-arcs -ftest-coverage"])
-
 # Python support.
 PYGOBJECT_REQUIRED=2.90
 

=== modified file 'libsignon-glib/Makefile.am'
--- libsignon-glib/Makefile.am	2015-12-02 08:57:16 +0000
+++ libsignon-glib/Makefile.am	2016-05-18 10:23:00 +0000
@@ -5,11 +5,14 @@
 	-I$(top_srcdir) \
 	-I$(srcdir) \
 	-I$(top_builddir) \
-	-I$(builddir) \
+	-I$(builddir)
+libsignon_glib_la_CFLAGS = \
 	$(DEPS_CFLAGS) \
+	$(COVERAGE_CFLAGS) \
 	-Wall -Werror -Wno-error=deprecated-declarations
 libsignon_glib_la_LIBADD = $(DEPS_LIBS)
 libsignon_glib_la_LDFLAGS = \
+	$(COVERAGE_LDFLAGS) \
 	-version-info 1:0:0 \
 	-export-symbols-regex '^signon_'
 
@@ -75,8 +78,7 @@
 	signon-auth-session.h \
 	signon-identity-info.h
 
-# This should come from `pkg-config --variable=interfaces_dir dbus-1`
-DBUS_INTERFACES_DIR = /usr/share/dbus-1/interfaces
+DBUS_INTERFACES_DIR = $(datadir)/dbus-1/interfaces
 
 sso-auth-service-gen.h sso-auth-service-gen.c: $(DBUS_INTERFACES_DIR)/com.google.code.AccountsSSO.SingleSignOn.AuthService.xml
 	$(AM_V_GEN)gdbus-codegen \
@@ -145,9 +147,9 @@
 	    --vtail "      { 0, NULL, NULL }\n    };\n    etype = g_@type@_register_static (g_intern_static_string (\"@EnumName@\"), values);\n  }\n  return etype;\n}\n" \
 	    signon-errors.h ) | \
 	    $(SED) -e 's/SEDSIGNON_ERROR_\([^,]*\)/SIGNOND_\1_ERR_NAME/' \
-	    > xgen-getc \
-	    && cp xgen-getc signon-errors-enum.c  \
-	    && rm -f xgen-getc
+	    > xgen-getc-enum \
+	    && cp xgen-getc-enum signon-errors-enum.c  \
+	    && rm -f xgen-getc-enum
 
 signon-errors-map.c: Makefile signon-errors.h
 	$(AM_V_GEN)( cd $(srcdir) && \
@@ -189,6 +191,7 @@
 	--warn-all
 Signon_1_0_gir_CFLAGS = \
 	-I$(top_srcdir) \
+	-I$(top_builddir) \
 	$(DEPS_CFLAGS)
 Signon_1_0_gir_LIBS = libsignon-glib.la
 Signon_1_0_gir_FILES = $(introspection_sources)

=== modified file 'libsignon-glib/signon-auth-session.c'
--- libsignon-glib/signon-auth-session.c	2016-05-04 09:45:51 +0000
+++ libsignon-glib/signon-auth-session.c	2016-05-18 09:17:09 +0000
@@ -419,8 +419,6 @@
 {
     g_return_if_fail (SIGNON_IS_AUTH_SESSION (self));
 
-    SignonAuthSessionPrivate *priv = self->priv;
-    g_return_if_fail (priv != NULL);
     g_return_if_fail (id >= 0);
 
     auth_session_check_remote_object(self);
@@ -477,9 +475,6 @@
                                                 gpointer user_data)
 {
     g_return_if_fail (SIGNON_IS_AUTH_SESSION (self));
-    SignonAuthSessionPrivate* priv = self->priv;
-
-    g_return_if_fail (priv != NULL);
 
     AuthSessionQueryAvailableMechanismsCbData *cb_data = g_slice_new0 (AuthSessionQueryAvailableMechanismsCbData);
     cb_data->self = self;

=== modified file 'libsignon-glib/signon-identity.c'
--- libsignon-glib/signon-identity.c	2016-05-04 09:21:44 +0000
+++ libsignon-glib/signon-identity.c	2016-05-18 09:17:09 +0000
@@ -949,9 +949,6 @@
 {
     g_return_if_fail (SIGNON_IS_IDENTITY (self));
 
-    SignonIdentityPrivate *priv = self->priv;
-    g_return_if_fail (priv != NULL);
-
     DEBUG ("%s %d", G_STRFUNC, __LINE__);
 
     IdentityVerifyCbData *cb_data = g_slice_new0 (IdentityVerifyCbData);
@@ -1308,9 +1305,6 @@
 {
     g_return_if_fail (SIGNON_IS_IDENTITY (self));
 
-    SignonIdentityPrivate *priv = self->priv;
-    g_return_if_fail (priv != NULL);
-
     DEBUG ("%s %d", G_STRFUNC, __LINE__);
 
     IdentityVoidData *operation_data = g_slice_new0 (IdentityVoidData);
@@ -1335,9 +1329,6 @@
 {
     g_return_if_fail (SIGNON_IS_IDENTITY (self));
 
-    SignonIdentityPrivate *priv = self->priv;
-    g_return_if_fail (priv != NULL);
-
     IdentityVoidCbData *cb_data = g_slice_new0 (IdentityVoidCbData);
     cb_data->self = self;
     cb_data->cb = (SignonIdentityVoidCb)cb;
@@ -1368,9 +1359,6 @@
 {
     g_return_if_fail (SIGNON_IS_IDENTITY (self));
 
-    SignonIdentityPrivate *priv = self->priv;
-    g_return_if_fail (priv != NULL);
-
     IdentityVoidCbData *cb_data = g_slice_new0 (IdentityVoidCbData);
     cb_data->self = self;
     cb_data->cb = (SignonIdentityVoidCb)cb;
@@ -1399,9 +1387,6 @@
 {
     g_return_if_fail (SIGNON_IS_IDENTITY (self));
 
-    SignonIdentityPrivate *priv = self->priv;
-    g_return_if_fail (priv != NULL);
-
     //TODO implement
 
     if (cb)
@@ -1424,9 +1409,6 @@
 {
     g_return_if_fail (SIGNON_IS_IDENTITY (self));
 
-    SignonIdentityPrivate *priv = self->priv;
-    g_return_if_fail (priv != NULL);
-
     //TODO implement
 
     if (cb)
@@ -1448,9 +1430,6 @@
 {
     g_return_if_fail (SIGNON_IS_IDENTITY (self));
 
-    SignonIdentityPrivate *priv = self->priv;
-    g_return_if_fail (priv != NULL);
-
     IdentityInfoCbData *cb_data = g_slice_new0 (IdentityInfoCbData);
     cb_data->self = self;
     cb_data->cb = cb;

=== added file 'm4/gcov.m4'
--- m4/gcov.m4	1970-01-01 00:00:00 +0000
+++ m4/gcov.m4	2016-05-18 09:45:05 +0000
@@ -0,0 +1,92 @@
+# Copyright 2012-2016 Canonical Ltd.
+#
+# This program is free software: you can redistribute it and/or modify it 
+# under the terms of the GNU General Public License version 3, as published 
+# by the Free Software Foundation.
+#
+# This program is distributed in the hope that it will be useful, but 
+# WITHOUT ANY WARRANTY; without even the implied warranties of 
+# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
+# PURPOSE.  See the GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License along 
+# with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+# Checks for existence of coverage tools:
+#  * gcov
+#  * lcov
+#  * genhtml
+#  * gcovr
+# 
+# Sets ac_cv_check_gcov to yes if tooling is present
+# and reports the executables to the variables LCOV, GCOVR and GENHTML.
+AC_DEFUN([AC_TDD_GCOV],
+[
+  AC_ARG_ENABLE(gcov,
+  AS_HELP_STRING([--enable-gcov],
+		 [enable coverage testing with gcov]))
+
+  AM_CONDITIONAL(HAVE_GCOV, test "x$enable_gcov" = "xyes")
+
+  if test "x$enable_gcov" = "xyes"; then
+  # we need gcc:
+  if test "$GCC" != "yes"; then
+    AC_MSG_ERROR([GCC is required for --enable-gcov])
+  fi
+
+  # Check if ccache is being used
+  AC_CHECK_PROG(SHTOOL, shtool, shtool)
+  if test "$SHTOOL"; then
+    AS_CASE([`$SHTOOL path $CC`],
+                [*ccache*], [gcc_ccache=yes],
+                [gcc_ccache=no])
+  fi
+
+  if test "$gcc_ccache" = "yes" && (test -z "$CCACHE_DISABLE" || test "$CCACHE_DISABLE" != "1"); then
+    AC_MSG_ERROR([ccache must be disabled when --enable-gcov option is used. You can disable ccache by setting environment variable CCACHE_DISABLE=1.])
+  fi
+
+  lcov_version_list="1.6 1.7 1.8 1.9 1.10 1.11 1.12"
+  AC_CHECK_PROG(LCOV, lcov, lcov)
+  AC_CHECK_PROG(GENHTML, genhtml, genhtml)
+
+  if test "$LCOV"; then
+    AC_CACHE_CHECK([for lcov version], glib_cv_lcov_version, [
+      glib_cv_lcov_version=invalid
+      lcov_version=`$LCOV -v 2>/dev/null | $SED -e 's/^.* //'`
+      for lcov_check_version in $lcov_version_list; do
+        if test "$lcov_version" = "$lcov_check_version"; then
+          glib_cv_lcov_version="$lcov_check_version (ok)"
+        fi
+      done
+    ])
+  else
+    lcov_msg="To enable code coverage reporting you must have one of the following lcov versions installed: $lcov_version_list"
+    AC_MSG_ERROR([$lcov_msg])
+  fi
+
+  case $glib_cv_lcov_version in
+    ""|invalid[)]
+      lcov_msg="You must have one of the following versions of lcov: $lcov_version_list (found: $lcov_version)."
+      AC_MSG_ERROR([$lcov_msg])
+      LCOV="exit 0;"
+      ;;
+  esac
+
+  if test -z "$GENHTML"; then
+    AC_MSG_ERROR([Could not find genhtml from the lcov package])
+  fi
+
+  # Remove all optimization flags from CFLAGS
+  changequote({,})
+  CFLAGS=`echo "$CFLAGS" | $SED -e 's/-O[0-9]*//g'`
+  changequote([,])
+
+  # Add the special gcc flags
+  COVERAGE_CFLAGS="--coverage -DG_DISABLE_ASSERTS -DG_DISABLE_CHECKS"
+  COVERAGE_CXXFLAGS="--coverage"	
+  COVERAGE_LDFLAGS="-lgcov"
+
+fi
+]) # AC_TDD_GCOV
+

